==> humhub-1.4.1.tar.gz: humhub-1.4.1/protected/humhub/modules/installer/messages/de/base.php <==
<?php
return array (
  '<strong>Admin</strong> Account' => '<strong>Administrator</strong> Konto',
  '<strong>Configuration</strong>' => '<strong>Konfiguration</strong>',
  '<strong>Congratulations</strong>. You\'re done.' => '<strong>Glückwunsch</strong>. Du hast die Installation abgeschlossen.',
  '<strong>Database</strong> Configuration' => '<strong>Datenbank</strong> Konfiguration',
  '<strong>Example</strong> contents' => '<strong>Beispiel</strong>inhalte',
  '<strong>System</strong> Check' => '<strong>System</strong> Check',
  '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Willkommen</strong> bei HumHub.<br />
Deinem Sozialem Netzwerk.',
  'Allow access for non-registered users to public content (guest access)' => 'Erlaube Zugriff auf öffentliche Inhalte für nicht registrierte Benutzer  (Gastzugriff)',
  'Allow friendships between members' => 'Freundschaften zwischen Mitgliedern erlauben',
  'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'Hier musst du deine Datenbankverbindungsdaten eingeben. Wenn Du Dir darüber nicht sicher bist, wende Dich bitte an Deinen Systemadministrator.',
  'Calvin Klein – Between love and madness lies obsession.' => 'Calvin Klein - Zwischen Liebe und Wahnsinn liegt Besessenheit.',
  'Check again' => 'Prüfe erneut',
  'Congratulations! Everything is ok and ready to start over!' => 'Glückwunsch! Alles ist in Ordnung und bereit zur Installation!',
  'Create Admin Account' => 'Erstelle Administrator-Konto',
  'Downloading & Installing Modules...' => 'Module herunterladen &amp; installieren...',
  'External users can register (show registration form on login)' => 'Externe Benutzer können sich registrieren (Registrierungsformular beim Login anzeigen)',
  'Here you can decide how new, unregistered users can access HumHub.' => 'Hier kannst Du entscheiden, wie neue, nicht registrierte Benutzer auf HumHub zugreifen können.',
  'Hostname' => 'Hostname',
  'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Hostname von deinem MySQL-Datenbankserver, (z.B. localhost wenn der MySQL-Server auf dem System läuft.)',
  'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub ist sehr flexibel und kann dank seiner verschiedenen Module für verschiedene Anwendungen angepasst und/oder erweitert werden. Die folgenden Module sind nur einige Beispiele und die, die wir für die von Dir gewählte Verwendung für sehr wichtig gehalten haben.<br /><br />Du kannst Module jederzeit später installieren oder entfernen. Weitere verfügbare Module findest Du nach der Installation im Admin-Bereich.',
  'I want to use HumHub for:' => 'Ich möchte HumHub benutzen für:',
  'Initializing database...' => 'Initialisiere Datenbank...',
  'My club' => 'Mein Club / Verein',
  'My community' => 'Meine Community',
  'My company (Social Intranet / Project management)' => 'Meine Firma (Social Intranet / Projektmanagement)',
  'My educational institution (school, university)' => 'Meine Bildungseinrichtung (Schule, Universität)',
  'Name of Database' => 'Name der Datenbank',
  'Name of your network' => 'Name deines Netzwerks',
  'Newly registered users have to be activated by an admin first' => 'Neu registrierte Benutzer müssen zuerst durch den Administrator freigeschaltet werden',
  'Next' => 'Weiter',
  'Nike – Just buy it. ;Wink;' => 'Nike - Just buy it ;Wink;',
  'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Dein neues Netzwerk benötigt natürlich einen Namen. Ändere den Standardnamen in einen Namen, der dir gefällt. (z.B. der Name deiner Firma, Organisation oder deines Vereines.)',
  'Ohh, something went wrong!' => 'Ooops! Irgendwas lief schief.',
  'Password' => 'Passwort',
  'Recommended <strong>Modules</strong>' => 'Empfohlene <strong>Module</strong>',
  'Registered members can invite new users via email' => 'Registrierte Benutzer können neue Benutzer per E-Mail einladen',
  'Security <strong>Settings</strong>' => 'Sicherheits<strong>einstellungen</strong>',
  'Set up example content (recommended)' => 'Beispielinhalte einrichten (empfohlen)',
  'Sign in' => 'Einloggen',
  'Skip this step, I want to set up everything manually' => 'Diesen Schritt überspringen. Ich möchte alles manuell einrichten',
  'Social Network <strong>Name</strong>' => 'Netzwerk <strong>Name</strong>',
  'The installation completed successfully! Have fun with your new social network.' => 'Die Installation wurde erfolgreich abgeschlossen! Viel Spaß mit deinem neuen Netzwerk.',
  'The name of the database you want to run HumHub in.' => 'Name der Datenbank, die von HumHub genutzt werden soll.',
  'This overview shows all system requirements of HumHub.' => 'Diese Übersicht zeigt alle Systemvoraussetzungen von HumHub.',
  'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Dieser Assistent installiert und konfiguriert Deine eigene HumHub-Instanz. <br /><br />Um fortzufahren, klicke auf Weiter.',
  'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'Um ein leeres Dashboard nach der ersten Anmeldung zu vermeiden, kann HumHub Beispielinhalte für Dich installieren. Diese geben Dir einen guten Überblick darüber, wie HumHub funktioniert. Du kannst die einzelnen Inhalte jederzeit löschen.',
  'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Um die Konfiguration zu vereinfachen, haben wir für die gängigsten Anwendungsfälle vordefinierte Setups mit verschiedenen Optionen für Module und Einstellungen. Du kannst sie im nächsten Schritt anpassen.',
  'Username' => 'Benutzername',
  'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Wir suchen nach tollen Slogans bekannter Marken. Vielleicht kannst du dir ein paar Beispiele einfallen lassen?',
  'Welcome Space' => 'Willkommens-Space',
  'Yay! I\'ve just installed HumHub ;Cool;' => 'Yay! Ich habe gerade HumHub installiert ;Cool;',
  'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Fast geschafft! Fülle in diesem Schritt das Eingabeformular aus, um das Administrator-Konto zu erstellen. Mit diesem Konto kannst du das ganze Netzwerk verwalten.',
  'Your MySQL password.' => 'Dein MySQL Passwort',
  'Your MySQL username' => 'Dein MySQL Benutzername',
  'Your first sample space to discover the platform.' => 'Dein erstes Beispiel, um die Plattform zu entdecken',
);

==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/installer/messages/de/base.php <==
<?php
return array (
  '<strong>Admin</strong> Account' => '<strong>Administrator</strong> Konto',
  '<strong>Configuration</strong>' => '<strong>Konfiguration</strong>',
  '<strong>Congratulations</strong>. You\'re done.' => '<strong>Glückwunsch</strong>. Du hast die Installation abgeschlossen.',
  '<strong>Database</strong> Configuration' => '<strong>Datenbank</strong> Konfiguration',
  '<strong>Example</strong> contents' => '<strong>Beispiel</strong>inhalte',
  '<strong>System</strong> Check' => '<strong>System</strong> Check',
  '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Willkommen</strong> bei HumHub.<br />
Deinem Sozialen Netzwerk.',
  'Allow access for non-registered users to public content (guest access)' => 'Erlaube Zugriff auf öffentliche Inhalte für nicht registrierte Benutzer  (Gastzugriff)',
  'Allow friendships between members' => 'Freundschaften zwischen Mitgliedern erlauben',
  'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'Hier musst du deine Datenbankverbindungsdaten eingeben. Wenn du dir darüber nicht sicher bist, wende dich bitte an deinen Systemadministrator.',
  'Calvin Klein – Between love and madness lies obsession.' => 'Calvin Klein - Zwischen Liebe und Wahnsinn liegt Besessenheit.',
  'Check again' => 'Prüfe erneut',
  'Congratulations! Everything is ok and ready to start over!' => 'Glückwunsch! Alles ist in Ordnung und bereit zur Installation!',
  'Create Admin Account' => 'Erstelle Administrator-Konto',
  'Downloading & Installing Modules...' => 'Module herunterladen &amp; installieren ...',
  'External users can register (show registration form on login)' => 'Externe Benutzer können sich registrieren (Registrierungsformular beim Login anzeigen)',
  'Here you can decide how new, unregistered users can access HumHub.' => 'Hier kannst du entscheiden, wie neue, nicht registrierte Benutzer auf HumHub zugreifen können.',
  'Hostname' => 'Hostname',
  'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Hostname von deinem MySQL-Datenbankserver, (z. B. localhost wenn der MySQL-Server auf dem System läuft.)',
  'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub ist sehr flexibel und kann dank seiner verschiedenen Module für verschiedene Anwendungen angepasst und/oder erweitert werden. Die folgenden Module sind nur einige Beispiele und die, die wir für die von dir gewählte Verwendung für sehr wichtig gehalten haben.<br /><br />Du kannst Module jederzeit später installieren oder entfernen. Weitere verfügbare Module findest du nach der Installation im Admin-Bereich.',
  'I want to use HumHub for:' => 'Ich möchte HumHub benutzen für:',
  'Initializing database...' => 'Initialisiere Datenbank ...',
  'My club' => 'Mein Club / Verein',
  'My community' => 'Meine Community',
  'My company (Social Intranet / Project management)' => 'Meine Firma (Social Intranet / Projektmanagement)',
  'My educational institution (school, university)' => 'Meine Bildungseinrichtung (Schule, Universität)',
  'Name of Database' => 'Name der Datenbank',
  'Name of your network' => 'Name deines Netzwerks',
  'Newly registered users have to be activated by an admin first' => 'Neu registrierte Benutzer müssen zuerst durch den Administrator freigeschaltet werden',
  'Next' => 'Weiter',
  'Nike – Just buy it. :wink:' => 'Nike - Just buy it :wink:',
  'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Dein neues Netzwerk benötigt natürlich einen Namen. Ändere den Standardnamen in einen Namen, der dir gefällt. (z. B. der Name deiner Firma, Organisation oder deines Vereines.)',
  'Ohh, something went wrong!' => 'Ooops! Irgendwas lief schief.',
  'Password' => 'Passwort',
  'Recommended <strong>Modules</strong>' => 'Empfohlene <strong>Module</strong>',
  'Registered members can invite new users via email' => 'Registrierte Benutzer können neue Benutzer per E-Mail einladen',
  'Security <strong>Settings</strong>' => 'Sicherheits<strong>einstellungen</strong>',
  'Set up example content (recommended)' => 'Beispielinhalte einrichten (empfohlen)',
  'Sign in' => 'Einloggen',
  'Skip this step, I want to set up everything manually' => 'Diesen Schritt überspringen. Ich möchte alles manuell einrichten',
  'Social Network <strong>Name</strong>' => 'Netzwerk <strong>Name</strong>',
  'The installation completed successfully! Have fun with your new social network.' => 'Die Installation wurde erfolgreich abgeschlossen! Viel Spaß mit deinem neuen Netzwerk.',
  'The name of the database you want to run HumHub in.' => 'Name der Datenbank, die von HumHub genutzt werden soll.',
  'This overview shows all system requirements of HumHub.' => 'Diese Übersicht zeigt alle Systemvoraussetzungen von HumHub.',
  'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Dieser Assistent installiert und konfiguriert deine eigene HumHub-Instanz. <br /><br />Um fortzufahren, klicke auf Weiter.',
  'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'Um ein leeres Dashboard nach der ersten Anmeldung zu vermeiden, kann HumHub Beispielinhalte für dich installieren. Diese geben dir einen guten Überblick darüber, wie HumHub funktioniert. Du kannst die einzelnen Inhalte jederzeit löschen.',
  'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Um die Konfiguration zu vereinfachen, haben wir für die gängigsten Anwendungsfälle vordefinierte Setups mit verschiedenen Optionen für Module und Einstellungen. Du kannst sie im nächsten Schritt anpassen.',
  'Username' => 'Benutzername',
  'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Wir suchen nach tollen Slogans bekannter Marken. Vielleicht kannst du dir ein paar Beispiele einfallen lassen?',
  'Welcome Space' => 'Willkommens-Space',
  'Yay! I\'ve just installed HumHub :sunglasses:' => 'Yay! Ich habe gerade HumHub installiert :sunglasses:',
  'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Fast geschafft! Fülle in diesem Schritt das Eingabeformular aus, um das Administrator-Konto zu erstellen. Mit diesem Konto kannst du das ganze Netzwerk verwalten.',
  'Your MySQL password.' => 'Dein MySQL Passwort',
  'Your MySQL username' => 'Dein MySQL Benutzername',
  'Your first sample space to discover the platform.' => 'Dein erstes Beispiel, um die Plattform zu entdecken',
);
